/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.
 *| (C) Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |	
 *+--------------------------------------------------------------------------------------+
 */

package itso.ad.business.delegate.ejb;

import itso.ad.business.framework.exception.ServiceException;
import itso.ad.business.framework.interfaces.delegates.IPiggyBankBusinessDelegate;
import itso.ad.business.ejb.facade.PiggyBankControllerLocal;
import itso.ad.business.ejb.facade.PiggyBankControllerLocalHome;
import itso.ad.business.framework.interfaces.to.ICustomerTO;
import itso.ad.common.logging.LogHelper;
import itso.ad.common.util.HomeFactory;

import java.util.List;

import javax.ejb.CreateException;
import javax.naming.NamingException;

public class PiggyBankEJBDelegateImpl implements IPiggyBankBusinessDelegate {
	private static LogHelper log = LogHelper.getInstance(PiggyBankEJBDelegateImpl.class);

	private static final String PIGGY_BANK_CONTROLLER_EJB_REF = "ejb/PiggyBankController";

	private PiggyBankControllerLocal piggyBankControllerLocal;

	/**
	 * Constructor for PiggyBankEJBDelegateImpl.
	 */
	public PiggyBankEJBDelegateImpl() throws ServiceException {

		try {
			
			PiggyBankControllerLocalHome piggyBankControllerLocalHome = (PiggyBankControllerLocalHome) HomeFactory.getInstance().getHome(PIGGY_BANK_CONTROLLER_EJB_REF);
			piggyBankControllerLocal = piggyBankControllerLocalHome.create();
			
		} catch (NamingException e) {
			log.error(e.getMessage(), e);
			throw new ServiceException(e.getMessage(), e);
		} catch (CreateException e) {
			log.error(e.getMessage(), e);
			throw new ServiceException(e.getMessage(), e);
		}
	}

	/**
	 * @see itso.ad.business.interfaces.delegate.IPiggyBankBusinessDelegate#getCustomerById(String)
	 */
	public ICustomerTO getCustomerById(String customerId) {

		ICustomerTO customerTO = null;

		try {
			customerTO = piggyBankControllerLocal.getCustomerById(customerId);
		} catch (ServiceException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}


		return customerTO;
	}

	/**
	 * @see itso.ad.business.interfaces.delegate.IPiggyBankBusinessDelegate#transfer(String, String, String, int)
	 */
	public void transfer(ICustomerTO customer, String debitAccount, String creditAccount, Integer amountToTransfer) {

			String customerId = customer.getId();
			try {
				piggyBankControllerLocal.transfer(customerId, debitAccount, creditAccount, amountToTransfer);
			} catch (ServiceException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
	}

	/**
	 * @see itso.ad.business.interfaces.delegate.IPiggyBankBusinessDelegate#getBalance(String, String)
	 */
	public Integer getBalance(ICustomerTO customer, String accountNumber) {
		Integer balance=null;
		String customerId = customer.getId();
		try {
			balance = piggyBankControllerLocal.getBalance(customerId, accountNumber);
		} catch (ServiceException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return balance;
	}

	/**
	 * @see itso.ad.business.interfaces.delegate.IPiggyBankBusinessDelegate#cashCheck(String, int, String)
	 */
	public void cashCheck(String checkReference, Integer checkAmount, String accountToCredit) {

		try {
			piggyBankControllerLocal.cashCheck(checkReference, checkAmount, accountToCredit);
		} catch (ServiceException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}

	/**
	 * @see itso.ad.business.interfaces.delegate.IPiggyBankBusinessDelegate#getAccountsByCustomer(ICustomerTO)
	 */
	public List getAccountsByCustomer(ICustomerTO customer) {

		List accounts = null;
		try {
			accounts = piggyBankControllerLocal.getAccountsByCustomerId(customer.getId());
		} catch (ServiceException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		return accounts;
	}

}
