/*
 *+--------------------------------------------------------------------------------------+
 *| Licensed Materials - Use restricted, please refer to the "Samples Gallery" terms and |
 *| conditions in the IBM International Program License Agreement.						 |	
 *|  Copyright IBM Corporation 2003, 2004. All Rights Reserved.						 |
 *+--------------------------------------------------------------------------------------+
 */
package itso.ad.business.framework.factory;

import itso.ad.business.framework.exception.ServiceException;
import itso.ad.business.framework.interfaces.delegates.AbstractBusinessDelegateFactory;
import itso.ad.business.framework.interfaces.delegates.IPiggyBankBusinessDelegate;




public abstract class BusinessDelegateFactory implements AbstractBusinessDelegateFactory {
	
	//private static LogHelper //log = //logHelper.getInstance(BusinessDelegateFactory.class);
	
	private static AbstractBusinessDelegateFactory delegateFactory;

	/**
	 * Constructor for BusinessDelegateFactory.
	 */
	private BusinessDelegateFactory() {
		super();
	}

	/**
	 * @see itso.ad.business.interfaces.delegate.AbstractBusinessDelegateFactory#createPiggyBankBusinessDelegate()
	 */
	public IPiggyBankBusinessDelegate createPiggyBankBusinessDelegate() throws ServiceException {
		return delegateFactory.createPiggyBankBusinessDelegate();
	}
	
	/**
	 * Used to initialize the business delegate factory.
	 * 
	 * @param factoryClassName <code>String</code> the implementing business factory class name.
	 * @exception <code>ServiceException</code> is thrown if error on factory initialization occures.
	 */
	public static void init(String factoryClassName) throws ServiceException{
		if (delegateFactory == null) {
			initFactory(factoryClassName);
		}	
	}
	
	/**
	 * Returns business delegate factory instance.
	 * 
	 * @return <code>AbstractBusinessDelegateFactory</code> the delegate factory instance.
	 * @exception <code>ServiceException</code> is thrown if error on factory initialization occures.
	 */
	public static AbstractBusinessDelegateFactory getInstance() throws ServiceException{
		if (delegateFactory == null) {
			throw new ServiceException("please initialize factory before calling getInstance !!");
		}
		return delegateFactory;	
	}	

	private static void initFactory(String factoryClassName) throws ServiceException{
		try {
			
			delegateFactory = (AbstractBusinessDelegateFactory)Class.forName(factoryClassName).newInstance();
			
		} catch (Exception e) {
			//log.error(e.getMessage(), e);
			throw new ServiceException(e.getMessage(), e);
		}
	}
}

